pub struct VisualizationConfig {
pub theme: VisualizationTheme,
pub default_chart_size: ChartSize,
pub color_palette: ColorPalette,
pub animation_enabled: bool,
pub high_dpi_enabled: bool,
pub export_formats: Vec<ExportFormat>,
}Expand description
Configuration for visualization settings
Fields
theme: VisualizationThemedefault_chart_size: ChartSizecolor_palette: ColorPaletteanimation_enabled: boolhigh_dpi_enabled: boolexport_formats: Vec<ExportFormat>Implementations
Sourceimpl VisualizationConfig
impl VisualizationConfig
Sourcepub fn dark_theme() -> Self
pub fn dark_theme() -> Self
Create a dark theme configuration preset optimized for dark backgrounds with carefully selected colors for good contrast and readability
Sourcepub fn high_contrast() -> Self
pub fn high_contrast() -> Self
Create a high contrast configuration preset for accessibility compliance using maximum contrast colors suitable for users with visual impairments
Sourcepub fn print_optimized() -> Self
pub fn print_optimized() -> Self
Create a configuration optimized for print/publication output with high DPI settings, static output, and print-friendly colors